@@ -4,33 +4,29 @@
 
 part of dart.async;
 
-/**
- * Indicates that loading of [libraryName] is deferred.
- *
- * This class is obsolete. Instead use the syntax:
- * import "library.dart" deferred as prefix;
- */
+/// Indicates that loading of [libraryName] is deferred.
+///
+/// This class is obsolete. Instead use the syntax:
+/// ```dart
+/// import "library.dart" deferred as prefix;
+/// ```
 @Deprecated("Dart sdk v. 1.8")
 class DeferredLibrary {
   final String libraryName;
-  final String uri;
+  final String? uri;
 
   const DeferredLibrary(this.libraryName, {this.uri});
 
-  /**
-   * Ensure that [libraryName] has been loaded.
-   *
-   * If the library fails to load, the Future will complete with a
-   * DeferredLoadException.
-   */
+  /// Ensure that [libraryName] has been loaded.
+  ///
+  /// If the library fails to load, the [Future] will complete with a
+  /// [DeferredLoadException].
   external Future<Null> load();
 }
 
-/**
- * Thrown when a deferred library fails to load.
- */
+/// Thrown when a deferred library fails to load.
 class DeferredLoadException implements Exception {
-  DeferredLoadException(String this._s);
+  DeferredLoadException(String message) : _s = message;
   String toString() => "DeferredLoadException: '$_s'";
   final String _s;
-}
\ No newline at end of file
+}
